@@ -184,7 +184,9 @@ class Move(ModelSQL, ModelView):
     def check_date(self):
         if (self.date < self.period.start_date
                 or self.date > self.period.end_date):
-            self.raise_user_error('date_outside_period', (self.rec_name,))
+            self.raise_user_error('date_outside_period', {
+                        'move': self.rec_name,
+                        })
 
     @classmethod
     def check_modify(cls, moves):
@@ -357,11 +359,13 @@ class Move(ModelSQL, ModelView):
                     move.period.post_move_sequence_used.id)
             cls.write([move], values)
 
+            keyfunc = lambda l: (l.party, l.account)
             to_reconcile = [l for l in move.lines
                 if ((l.debit == l.credit == Decimal('0'))
                     and l.account.reconcile)]
-            if to_reconcile:
-                Line.reconcile(to_reconcile)
+            to_reconcile = sorted(to_reconcile, key=keyfunc)
+            for _, zero_lines in groupby(to_reconcile, keyfunc):
+                Line.reconcile(list(zero_lines))
 
     @classmethod
     @ModelView.button
